<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Online_News
 */

if ( ! function_exists( 'online_news_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function online_news_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);
	$disable_date = online_news_get_option('disable_date');
	if('false'== !$disable_date){ 
	$posted_on = sprintf(
		'%s',
		'<a class="post-meta-date" href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
	} else{
		$posted_on ='';
	}
	$disable_author = online_news_get_option('disable_author');
	if('false'== !$disable_author){
		$byline = sprintf(
			esc_html_x( 'By %s', 'post author', 'online-news' ),
			'<a class="bypostauthor" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
		);
	} else{
		$byline ='';
	}

	echo '<div class="post-meta"><span class="post-meta-author">' . $byline . '</span>' . $posted_on . '</div>'; // WPCS: XSS OK.

}
endif;


if ( ! function_exists( 'online_news_category' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function online_news_category() {
// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( ' ' );
		if ( $categories_list ) {
			printf( '<span class="cat-links"> %1$s</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', ' ' );
		if ( $tags_list ) {
			printf( '<span class="tags-links"> %1$s</span>', $tags_list ); // WPCS: XSS OK.
		}
	}
}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
    /**
     * Shim for sites older than 5.2.
     *
     * @link https://core.trac.wordpress.org/ticket/12563
     */
    // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedFunctionFound
    function wp_body_open() {
        do_action( 'wp_body_open' ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    }
endif;
